@@ -6,14 +6,14 @@ use warnings;
 use Log::ger;
 
 use Exporter 'import';
-use App::FileSortUtils;
+use File::Util::Sort;
 use Perinci::Object;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-16'; # DATE
+our $DATE = '2023-11-28'; # DATE
 our $DIST = 'App-DownloadsDirUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our %SPEC;
 
@@ -58,7 +58,7 @@ excluding partial downloads (`*.part` files).
 
 MARKDOWN
         output_name => __PACKAGE__ . "::${which}_download",
-        base_name   => "App::FileSortUtils::$which",
+        base_name   => "File::Util::Sort::$which",
         modify_args => {
             dirs => sub {
                 my $arg_spec = shift;
@@ -74,7 +74,7 @@ MARKDOWN
             my %args = @_;
             $args{dirs} //= scalar list_downloads_dirs();
             $args{exclude_filename_pattern} //= qr/\.part\z/;
-            &{"App::FileSortUtils::$which"}(%args);
+            &{"File::Util::Sort::$which"}(%args);
         },
     );
     die "Can't generate ${which}_download(): $res->[0] - $res->[1]"
@@ -153,7 +153,7 @@ App::DownloadsDirUtils - Utilities related to downloads directories
 
 =head1 VERSION
 
-This document describes version 0.004 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-16.
+This document describes version 0.005 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-28.
 
 =head1 DESCRIPTION
 
